@@ -49,8 +49,6 @@
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
-#include <libgnome/gnome-desktop-item.h>
-
 #ifdef HAVE_STARTUP_NOTIFICATION
 #define SN_API_NOT_YET_FROZEN
 #include <libsn/sn.h>
@@ -61,6 +59,9 @@
 
 #define sure_string(s) ((s)!=NULL?(s):"")
 
+#undef GNOME_DISABLE_DEPRECATED
+#include <libgnome/gnome-desktop-item.h>
+
 struct _GnomeDesktopItem {
 	int refcount;
 
@@ -1731,6 +1732,7 @@ ditem_execute (const GnomeDesktopItem *item,
 	       gboolean use_current_dir,
 	       gboolean append_uris,
 	       gboolean append_paths,
+	       gboolean do_not_reap_child,
 	       GError **error)
 {
 	char **free_me = NULL;
@@ -1948,7 +1950,7 @@ ditem_execute (const GnomeDesktopItem *item,
 		if ( ! g_spawn_async (working_dir,
 				      real_argv,
 				      envp,
-				      G_SPAWN_SEARCH_PATH /* flags */,
+				      (do_not_reap_child ? G_SPAWN_DO_NOT_REAP_CHILD : 0) | G_SPAWN_SEARCH_PATH /* flags */,
 				      NULL, /* child_setup_func */
 				      NULL, /* child_setup_func_data */
 				      &ret /* child_pid */,
@@ -2101,6 +2103,7 @@ gnome_desktop_item_launch_on_screen_with_env (
 			     (flags & GNOME_DESKTOP_ITEM_LAUNCH_USE_CURRENT_DIR),
 			     (flags & GNOME_DESKTOP_ITEM_LAUNCH_APPEND_URIS),
 			     (flags & GNOME_DESKTOP_ITEM_LAUNCH_APPEND_PATHS),
+			     (flags & GNOME_DESKTOP_ITEM_LAUNCH_DO_NOT_REAP_CHILD),
 			     error);
 
 	return ret;
@@ -2659,11 +2662,8 @@ gnome_desktop_item_find_icon (GtkIconTheme *icon_theme,
 		char *icon_no_extension;
 		char *p;
 
-		if (icon_theme == NULL) {
-			icon_theme = gtk_icon_theme_new ();
-		} else {
-			g_object_ref (icon_theme);
-		}
+		if (icon_theme == NULL)
+			icon_theme = gtk_icon_theme_get_default ();
 		
 		icon_no_extension = g_strdup (icon);
 		p = strrchr (icon_no_extension, '.');
@@ -2695,8 +2695,6 @@ gnome_desktop_item_find_icon (GtkIconTheme *icon_theme,
 			}
 		}
 		
-		g_object_unref (icon_theme);
-		
 		g_free (icon_no_extension);
 	}
 
